==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/TANKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TANKID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TANKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TANKCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TANKID_Type", propOrder = {
    "depotid",
    "tankcode",
    "description"
})
public class TANKID_Type {

    @XmlElement(name = "DEPOTID", required = true)
    protected DEPOTID_Type depotid;
    @XmlElement(name = "TANKCODE")
    protected String tankcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété depotid.
     * 
     * @return
     *     possible object is
     *     {@link DEPOTID_Type }
     *     
     */
    public DEPOTID_Type getDEPOTID() {
        return depotid;
    }

    /**
     * Définit la valeur de la propriété depotid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPOTID_Type }
     *     
     */
    public void setDEPOTID(DEPOTID_Type value) {
        this.depotid = value;
    }

    /**
     * Obtient la valeur de la propriété tankcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTANKCODE() {
        return tankcode;
    }

    /**
     * Définit la valeur de la propriété tankcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTANKCODE(String value) {
        this.tankcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TANKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TANKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TANKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TANKCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TANKID_Type", propOrder = {
    "depotid",
    "tankcode",
    "description"
})
public class TANKID_Type {

    @XmlElement(name = "DEPOTID", required = true)
    protected DEPOTID_Type depotid;
    @XmlElement(name = "TANKCODE")
    protected String tankcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the depotid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPOTID_Type }
     *     
     */
    public DEPOTID_Type getDEPOTID() {
        return depotid;
    }

    /**
     * Sets the value of the depotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPOTID_Type }
     *     
     */
    public void setDEPOTID(DEPOTID_Type value) {
        this.depotid = value;
    }

    /**
     * Gets the value of the tankcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTANKCODE() {
        return tankcode;
    }

    /**
     * Sets the value of the tankcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTANKCODE(String value) {
        this.tankcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
